@@ -162,6 +162,8 @@ CREATE TABLE IF NOT EXISTS tools_object_tables
     "default" character varying COLLATE pg_catalog."default" NOT NULL DEFAULT ''::character varying,
     foreign_key boolean NOT NULL DEFAULT false,
     "unique" boolean NOT NULL DEFAULT false,
+    "mandatory" boolean NOT NULL DEFAULT false,
+    "project" character varying COLLATE pg_catalog."default" NOT NULL DEFAULT ''::character varying,
     CONSTRAINT tools_object_tables_pkey PRIMARY KEY (tools_object_tables_pkey),
     CONSTRAINT tools_object_tables_tools_objects_fkey FOREIGN KEY (tools_objects_fkey)
         REFERENCES tools_objects (tools_objects_pkey) MATCH SIMPLE
@@ -208,7 +210,6 @@ CREATE TABLE IF NOT EXISTS tools_parameters
     tools_parameter_groups_fkey bigint NOT NULL,
     parameter character varying COLLATE pg_catalog."default" NOT NULL DEFAULT ''::character varying,
     CONSTRAINT tools_parameters_pkey PRIMARY KEY (tools_parameters_pkey),
-    CONSTRAINT tools_parameters_parameter_key UNIQUE (parameter),
     CONSTRAINT tools_parameters_tools_parameter_groups_fkey FOREIGN KEY (tools_parameter_groups_fkey)
         REFERENCES tools_parameter_groups (tools_parameter_groups_pkey) MATCH SIMPLE
         ON UPDATE NO ACTION
@@ -216,6 +217,9 @@ CREATE TABLE IF NOT EXISTS tools_parameters
         DEFERRABLE
 );
 
+CREATE UNIQUE INDEX tools_parameters_parameter_parameter_groups_key
+ON tools_parameters(parameter, tools_parameter_groups_fkey);
+
 CREATE TABLE IF NOT EXISTS tools_parameter_values
 (
     tools_parameter_values_pkey serial NOT NULL,
@@ -253,6 +257,7 @@ CREATE TABLE IF NOT EXISTS tools_object_sql
     tools_version_fkey bigint NOT NULL,
     tools_objects_fkey bigint NOT NULL,
     name character varying COLLATE pg_catalog."default" NOT NULL DEFAULT ''::character varying,
+    comment character varying COLLATE pg_catalog."default" NOT NULL DEFAULT ''::character varying,
     sql_string character varying COLLATE pg_catalog."default" NOT NULL DEFAULT ''::character varying,
     CONSTRAINT tools_object_sql_pkey PRIMARY KEY (tools_object_sql_pkey),
     CONSTRAINT tools_object_sql_tools_objects_fkey FOREIGN KEY (tools_objects_fkey)
@@ -334,7 +339,9 @@ CREATE OR REPLACE VIEW v_tools_objects_tables_datatypes
     tools_object_tables."notnull",
     tools_object_tables."default",
     tools_object_tables.foreign_key,
-    tools_object_tables."unique"
+    tools_object_tables."unique",
+    tools_object_tables."mandatory",
+    tools_object_tables."project"
    FROM tools_object_tables
      JOIN tools_objects_tables_datatypes
      ON tools_object_tables.tools_objects_tables_datatypes_fkey = tools_objects_tables_datatypes.tools_objects_tables_datatypes_pkey;
@@ -454,9 +461,31 @@ INSERT INTO tools_parameters (parameter, tools_parameter_groups_fkey) VALUES
     ('Output file name', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Sql')),
     ('Output Name Space', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Sql')),
     ('Base file path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Perl')),
+    ('Plugin file path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Perl')),
+    ('Routes file path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Perl')),
+    ('Controller file path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Perl')),
+    ('Helpers file path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Perl')),
+    ('Template Source', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Perl')),
     ('Model file path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Perl')),
+    ('Template Source', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Angular')),
+    ('Interface file path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Angular')),
+    ('Component file path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Angular')),
+    ('Outputs', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Angular')),
+    ('Test file path', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Perl')),
+	('Outputs', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Perl')),
     ('Path to app', (select tools_parameter_groups_pkey from tools_parameter_groups WHERE parameter_group = 'Angular'));
 
+CREATE OR REPLACE VIEW v_tools_objects_sql AS
+SELECT tools_object_sql_pkey, tools_version_fkey, tools_objects_fkey, "name", sql_string, "comment"
+	FROM tools_object_sql;
+
+CREATE OR REPLACE VIEW v_tools_objects_active AS
+SELECT tools_objects_pkey, editnum, insby, insdatetime, modby, moddatetime, tools_version_fkey, "name", active, tools_object_types_fkey, tools_projects_fkey
+	FROM tools_objects WHERE tools_object_types_fkey = 1 and active = true;
+
+CREATE OR REPLACE VIEW v_tools_object_table_active AS
+SELECT tools_object_tables_pkey, editnum, insby, insdatetime, modby, moddatetime, tools_version_fkey, tools_objects_fkey, fieldname, "length", "scale", (SELECT name FROM tools_objects_tables_datatypes WHERE tools_objects_tables_datatypes_pkey = tools_objects_tables_datatypes_fkey) as datatype, tools_objects_tables_datatypes_fkey, active, visible, "notnull", "default", foreign_key, "unique", "mandatory", "project"
+	FROM tools_object_tables;
 
 -- 1 down
 
